package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsPlanRepair;
import com.hw.dms.domain.DmsPlanRepairDetail;

/**
 * 检修计划信息Mapper接口
 *
 * @author Open Platform
 * @date 2024-01-15
 */
public interface DmsPlanRepairMapper
{
    /**
     * 查询检修计划信息
     *
     * @param planRepairId 检修计划信息主键
     * @return 检修计划信息
     */
    public DmsPlanRepair selectDmsPlanRepairByPlanRepairId(Long planRepairId);

    /**
     * 查询检修计划信息列表
     *
     * @param dmsPlanRepair 检修计划信息
     * @return 检修计划信息集合
     */
    public List<DmsPlanRepair> selectDmsPlanRepairList(DmsPlanRepair dmsPlanRepair);

    /**
     * 新增检修计划信息
     *
     * @param dmsPlanRepair 检修计划信息
     * @return 结果
     */
    public int insertDmsPlanRepair(DmsPlanRepair dmsPlanRepair);

    /**
     * 修改检修计划信息
     *
     * @param dmsPlanRepair 检修计划信息
     * @return 结果
     */
    public int updateDmsPlanRepair(DmsPlanRepair dmsPlanRepair);

    /**
     * 删除检修计划信息
     *
     * @param planRepairId 检修计划信息主键
     * @return 结果
     */
    public int deleteDmsPlanRepairByPlanRepairId(Long planRepairId);

    /**
     * 批量删除检修计划信息
     *
     * @param planRepairIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsPlanRepairByPlanRepairIds(Long[] planRepairIds);

    /**
     * 批量删除检修计划明细
     *
     * @param planRepairIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsPlanRepairDetailByPlanRepairIds(Long[] planRepairIds);

    /**
     * 批量新增检修计划明细
     *
     * @param dmsPlanRepairDetailList 检修计划明细列表
     * @return 结果
     */
    public int batchDmsPlanRepairDetail(List<DmsPlanRepairDetail> dmsPlanRepairDetailList);


    /**
     * 通过检修计划信息主键删除检修计划明细信息
     *
     * @param planRepairId 检修计划信息ID
     * @return 结果
     */
    public int deleteDmsPlanRepairDetailByPlanRepairId(Long planRepairId);


    //根据jobid获取cron表达式
    String getCron(Long jobId);
}
